@@ -17,11 +17,11 @@ Text::Amuse::Compile - Compiler for Text::Amuse
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -70,6 +70,11 @@ The EPUB
 
 The bare HTML, non <head>
 
+=item extra
+
+An hashref of key/value pairs to pass to each template in the
+C<options> namespace.
+
 =back
 
 Template directory:
@@ -108,6 +113,10 @@ sub new {
 
     $self->{report_failure_sub} = delete $params{report_failure_sub};
 
+    if (my $extraref = delete $params{extra}) {
+        $self->{extra} = { %$extraref };
+    }
+
     # options passed, null out and reparse the params
     if (%params) {
         foreach my $k (qw/pdf a4_pdf lt_pdf epub html bare_html tex/) {
@@ -147,6 +156,16 @@ sub templates {
     return shift->{templates};
 }
 
+sub extra {
+    my $self = shift;
+    my $hashref = $self->{extra};
+    my %out;
+    # do a shallow copy before returning
+    if ($hashref) {
+        %out = %$hashref;
+    }
+    return %out;
+}
 
 =head2 METHODS
 
@@ -231,6 +250,7 @@ sub _compile_file {
                 name => $name,
                 suffix => $suffix,
                 templates => $self->templates,
+                options => { $self->extra },
                );
 
     my $muse = Text::Amuse::Compile::File->new(%args);
